Package: GA4GHclient
Type: Package
Title: A Bioconductor package for accessing GA4GH API data servers
Version: 1.37.0
Authors@R: c(person("Welliton", "Souza", email = "well309@gmail.com",
    role = c("aut", "cre")),
    person("Benilton", "Carvalho", email = "benilton@unicamp.br", role = "ctb"),
    person("Cristiane", "Rocha", email = "crirocha@gmail.com", role = "ctb"))
Description: GA4GHclient provides an easy way to access public data servers
    through Global Alliance for Genomics and Health (GA4GH) genomics API. It
    provides low-level access to GA4GH API and translates response data into
    Bioconductor-based class objects.
License: GPL (>= 2)
Depends: R (>= 3.5.0), S4Vectors
Imports: BiocGenerics, Biostrings, dplyr, Seqinfo, GenomicRanges, httr,
        IRanges, jsonlite, methods, VariantAnnotation
Suggests: GenomeInfoDb, AnnotationDbi, BiocStyle, DT, knitr,
        org.Hs.eg.db, rmarkdown, testthat,
        TxDb.Hsapiens.UCSC.hg19.knownGene
RoxygenNote: 7.3.2
VignetteBuilder: knitr
URL: https://github.com/labbcb/GA4GHclient
BugReports: https://github.com/labbcb/GA4GHclient/issues
biocViews: DataRepresentation, ThirdPartyClient
git_url: https://git.bioconductor.org/packages/GA4GHclient
git_branch: devel
git_last_commit: 7d0549e
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:43:26 UTC; biocbuild
Author: Welliton Souza [aut, cre],
  Benilton Carvalho [ctb],
  Cristiane Rocha [ctb]
Maintainer: Welliton Souza <well309@gmail.com>
