# Generated by roxygen2: do not edit by hand

export(HGVSnames)
export(getBiosample)
export(getCallSet)
export(getDataset)
export(getExpressionLevel)
export(getFeature)
export(getFeatureSet)
export(getIndividual)
export(getReadGroupSet)
export(getReference)
export(getReferenceSet)
export(getRnaQuantification)
export(getRnaQuantificationSet)
export(getVariant)
export(getVariantAnnotationSet)
export(getVariantSet)
export(listReferenceBases)
export(makeVCFFromGA4GHResponse)
export(makeVCFHeaderFromGA4GHResponse)
export(searchBiosamples)
export(searchCallSets)
export(searchDatasets)
export(searchExpressionLevels)
export(searchFeatureSets)
export(searchFeatures)
export(searchIndividuals)
export(searchPhenotypeAssociationSets)
export(searchPhenotypeAssociations)
export(searchReadGroupSets)
export(searchReads)
export(searchReferenceSets)
export(searchReferences)
export(searchRnaQuantificationSets)
export(searchRnaQuantifications)
export(searchVariantAnnotationSets)
export(searchVariantAnnotations)
export(searchVariantSets)
export(searchVariants)
export(searchVariantsByGRanges)
importClassesFrom(GenomicRanges,GRangesList)
importFrom(Biostrings,BString)
importFrom(Biostrings,DNAStringSet)
importFrom(GenomicRanges,makeGRangesFromDataFrame)
importFrom(IRanges,CharacterList)
importFrom(IRanges,DataFrameList)
importFrom(S4Vectors,DataFrame)
importFrom(S4Vectors,Rle)
importFrom(VariantAnnotation,"header<-")
importFrom(VariantAnnotation,VCF)
importFrom(VariantAnnotation,VCFHeader)
importFrom(VariantAnnotation,header)
importFrom(dplyr,"%>%")
importFrom(dplyr,bind_rows)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(dplyr,starts_with)
importFrom(httr,GET)
importFrom(httr,POST)
importFrom(httr,accept_json)
importFrom(httr,content)
importFrom(httr,content_type_json)
importFrom(httr,http_error)
importFrom(httr,http_status)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(jsonlite,unbox)
importFrom(methods,as)
importMethodsFrom(BiocGenerics,as.data.frame)
importMethodsFrom(BiocGenerics,end)
importMethodsFrom(BiocGenerics,lengths)
importMethodsFrom(BiocGenerics,start)
importMethodsFrom(Seqinfo,seqnames)
