# GA4GHclient

[![Travis-CI Build Status](https://travis-ci.org/labbcb/GA4GHclient.svg?branch=master)](https://travis-ci.org/labbcb/GA4GHclient)
[![codecov](https://codecov.io/github/labbcb/GA4GHclient/branch/master/graphs/badge.svg)](https://codecov.io/github/labbcb/GA4GHclient) 

GA4GHclient provides an easy way to access public data servers through Global Alliance for Genomics and Health (GA4GH) genomics API.
It provides low-level access to GA4GH API and translates response data into Bioconductor-based class objects.

There are three available data servers that use GA4GH API. If you known more public data servers compatible with GA4GH API please let us know.

- [Hosting Thousand Genomes Project](http://1kgenomes.ga4gh.org/)
- [Ensembl REST API](https://rest.ensembl.org/)
- [BRCA Exchange GA4GH API](http://brcaexchange.org/backend/data/ga4gh/v0.6.0a7/)
